---
name: Bug report
about: Create an issue to help us improve
title: ''
labels: ['bug']
assignees: ''

---

Have you read the [documentation](https://ggozad.github.io/oterm/)?

Have you checked [closed issues](https://github.com/ggozad/oterm/issues?q=is%3Aissue+is%3Aclosed)?

Are you running the most [recent version of oterm](https://pypi.org/search/?q=oterm)?

## The bug

Include any useful information from the [logs](https://ggozad.github.io/oterm/development/) and/or full traceback.

Include your OS, python version and information about how you installed oterm.

Please give a brief but clear explanation of the issue and how we can reproduce it. Feel free to add screenshots.
